#
# Installation script for confman Version 1.11 
#
# written by Bernd Boeker for easier installation
#




# Some important definitions
SYSTEM_CONFMAN_HOME=/opt/comm/lib/confman
USER_CONFMAN_HOME=$HOME/confman
SYSTEM_BIN_DIR=/opt/comm/bin
USER_BIN_DIR=$HOME/bin

TAR=tar

PWD=`pwd`
BIN_FILE=$PWD/confman.bin.tar
DAT_FILE=$PWD/confman.dat.tar
HELP_FILE=$PWD/confman.help.tar

#  End of user configurable part.
#  There should be no need to change things below this line.
#
#########################################################################

#
# first shell dependend definitions
if [ $INST_SH = "bash" ]; then
	ECHON='echo -n'
else
	ECHON=echo
fi

# Some nice informative messages
echo
echo
cat << END_OF_WELCOME

                         Confman 1.11 Installation
                         ==========================


Welcome to the installation script of Confman version 1.11. Confman is a
conferencing management system using the MBone tools like vat, nv, ivs,
vic or wb. If you have questions about Confman read the file README.

Confman is licenced software. If you want to use Confman you have to agree
to the license conditions. Please read the file LICENSE.

Confman can be installed locally in your home partition or in a system
directory. If you want a system installation you have to run the install
script as root.


(c) Lehrgebiet Rechnernetze und Verteilte Systeme, Universitaet Hannover

            Press ENTER to continue or Ctrl-C to exit.

END_OF_WELCOME

read TEMP
clear

# check for existence of old confman files

# check user id
TEMP=`type id` 2>/dev/null

if [ `echo $?` ]; then
	if [ `whoami` = "root" ]; then MYUID=0; else MYUID=1; fi
else
	MYUID=`id|sed s/uid=//|sed s/\(.*//`
fi

if [ `expr $MYUID` -eq 0 ]; then
	echo
	echo
	echo Doing the confman system installation.
	BIN_DIR=$SYSTEM_BIN_DIR
	CONFMAN_HOME=$SYSTEM_CONFMAN_HOME
else
	echo
	echo
	echo Doing the confman private installation.
	echo
	echo If you want to do the Confman system installation you have to exit here,
	echo login as root and execute install.sh again.
	BIN_DIR=$USER_BIN_DIR
	CONFMAN_HOME=$USER_CONFMAN_HOME
fi

CORRECT="n"

until [ $CORRECT = "y" ]; do
	# ask for installation directories
	echo
	echo
	echo
	echo "              Enter installation directories"
	echo "              =============================="
	echo
	echo "Enter the directory in which you want to put the"
	$ECHON "Confman binaries ($BIN_DIR): "
	read TEMP
	if [ $TEMP ]; then BIN_DIR=$TEMP; fi
	echo
	echo "This will be the directory where the configuration files"
	$ECHON "will be placed ($CONFMAN_HOME): "
	read TEMP 
	if [ $TEMP ]; then CONFMAN_HOME=$TEMP; fi

	# print installation directories to stdout
	echo
	echo
	echo "                Check path names"
	echo "                ================"
	echo
	echo "Confman now will be installed into the directory: $BIN_DIR"
	echo
	echo "The Confman data files are placed into the directory: $CONFMAN_HOME"
	echo 
	echo
	$ECHON "Is this correct (y/N)? "
	read CORRECT
	if [ $CORRECT ]; then echo; else CORRECT="n"; fi
done

# check for existence of directories
if [ ! -d $BIN_DIR ]; then
	echo
	echo "The directory '$BIN_DIR' doesn't exist, creating it."
	mkdir $BIN_DIR
fi

if [ ! -d $CONFMAN_HOME ]; then
	echo "The directory '$CONFMAN_HOME' doesn't exist, creating it."
	mkdir $CONFMAN_HOME
else
	# check for old help files
	if [ -d $CONFMAN_HOME/help ]; then
	  echo
	  echo "               Delete old help files?"
	  echo "               ======================"
	  echo
	  echo
	  echo "There is an old help file directory. Do you want to delete the old"
	  $ECHON "help files? (Y/n) "
	  read DELETE
	  if [ $DELETE ]; then echo; else DELETE="y"; fi
	  if [ $DELETE = "y" ]; then
	    rm -rf $CONFMAN_HOME/help
	  fi
	  echo
	  echo Old help files have been deleted.
	fi	
fi

# check for an existing help directory
if [ -d $CONFMAN_HOME/help ]; then
	# found old help files, installation of new help files required
	echo
	echo
	echo
	echo "I've found an old help file directory, installation of new help files"
	echo "is required."
	echo
	echo "Press ENTER to continue or Ctrl-C to abort."
	read TEMP
	INSTALL_HELP="y"
else
	# Ask for installing help files
	echo
	echo
	echo "                      Install new help files?"
	echo "                      ======================="
	echo
	echo
	echo "Do you want to install the help files?"
	echo "If you don't install the help files locally confman will load them"
	echo "automatically from http://www.rvs.uni-hannover.de."
	echo
	$ECHON "Install help files? (y/N) "
	read INSTALL_HELP
	if [ $INSTALL_HELP ]; then echo; else INSTALL_HELP="n"; fi
fi

# untar files
echo "Extracting binaries, please wait ..."
cd $BIN_DIR
$TAR -xf $BIN_FILE
cd $CONFMAN_HOME/..
echo "Extracting data files, please wait ..."
$TAR -xf $DAT_FILE
if [ $INSTALL_HELP = "y" ]; then
  echo "Extracting help files, please wait ..."
  $TAR -xf $HELP_FILE
fi
cd $PWD

# check $PATH
TPATH=`echo "$PATH"|grep "$BIN_DIR"`
if [ $TPATH ]; then
	echo Your path is ok.
else
	echo
	echo
	echo "WARNING! Your installation path ist not part of of your path. Edit your"
	echo "login files to append the entry $BIN_DIR to the PATH environment variable."
	echo
	echo Press ENTER to continue.
	read TEMP
fi

# clean up
$ECHON "Do you want to remove all tar files(y/N)?"
read TEMP
if [ $TEMP ]; then echo; else TEMP="n"; fi

if [ $TEMP = "y" ]; then
	rm $DAT_FILE $BIN_FILE $HELP_FILE
fi

# Installation complete messages
clear
cat << END_OF_COMPLETE
                       Installation complete
                       =====================

The installation is now complete. Now you can start the conference managing
system just by typing 'confman', all further configuration will be done then.

END_OF_COMPLETE

# start confman
if [ ! `expr $MYUID` = 0 ]; then
	$ECHON "Do you want to start Confman now(y/N)?"
	read START
	if [ $START ]; then echo; else START="n"; fi

	if [ $START = "y" ]; then
		$BIN_DIR/confman
	fi
fi

if [ $TPATH ]; then
	echo
else
	echo "REMEMBER TO ADD '$BIN_DIR' TO YOUR PATH VARIABLE."
	echo "If you don't know how to do it ask your system administrator."
fi

#Thank You for using Confman. If you have want to test it try to call the
#"automatic conference responser" confman@rvs.uni-hannover.de via Confman.
#You will hear some nice music, see a picture of our SGI Indy and can write
#your messages to the whiteboard. confman is online only sometimes.

cat << END_OF_THANKS

If you have problems with the installation mail fricke@rvs.uni-hannover.de.

Bye.
END_OF_THANKS

exit 0
